@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008_001;
 
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 use parent qw( Test::Builder::Module );
 our @EXPORT = qw( synopsis_ok all_synopsis_ok );
@@ -92,6 +92,7 @@ sub _extract_synopsis
 package
   Test::Synopsis::Parser; # on new line to avoid indexing
 
+use Pod::Simple 3.09;
 use parent 'Pod::Simple';
 
 sub new
@@ -166,7 +167,7 @@ __END__
 =encoding utf-8
 
 =for stopwords Goro blogged Znet Zoffix DOHERTY Doherty
-  KRYDE Ryde ZOFFIX Gr nauer Grünauer pm HEREDOC HEREDOCs
+  KRYDE Ryde ZOFFIX Gr nauer Grünauer pm HEREDOC HEREDOCs DROLSKY
 
 =for test_synopsis $main::for_checked=1
 
@@ -351,6 +352,8 @@ Zoffix Znet <cpan (at) zoffix.com>
 
 =over 4
 
+=item * Dave Rolsky (L<DROLSKY|https://metacpan.org/author/DROLSKY>)
+
 =item * Kevin Ryde (L<KRYDE|https://metacpan.org/author/KRYDE>)
 
 =item * Marcel Grünauer (L<MARCEL|https://metacpan.org/author/MARCEL>)
